/**---------------------------------------------------------------------
***  
***  file:    formdemo.c
***
***  project:  Motif Widgets example programs
***
***  description:  This program creates a form widget with four
***                 push button widgets.
***  
***-------------------------------------------------------------------*/

/*   App-defaults file FOrmdemo
*** 
***  *keyboardFocusPolicy:	POINTER
***  *XmPushButton.background:	midnight blue
***  *XmPushButton.foreground:	white
***  *XmPushButton*height:	30
***  *XmPushButton*width:	80
***  *pb1.labelString:	Button 1
***  *pb2.labelString:	Button 2
***  *pb3.labelString:	Button 3
***  *pb4.labelString:	Button 4
***  *form.background: light blue
***  *form.width:	185
***  *form.height:	85
***  
*/

/*  include files  */

#include <stdio.h>
#include <X11/Intrinsic.h>
#include <Xm/Xm.h>
#include <Xm/PushB.h>
#include <Xm/Form.h>


/*  Functions defined in this program  */

void main();
void activateCB(); /* Callback for the pushbutton */


/*  Global variables  */

XmString btn_text;  /* button label pointer for compound string */


/*-------------------------------------------------------------
**  main - Main logic for formdemo
*/
void main (argc,argv)
unsigned int argc;
char **argv;
{
  Widget       toplevel;    /*  Shell widget         */
  Widget       form;        /*  Form widget          */
  Widget       button[4];      /*  Pushbutton widget    */
  static char  *pbname[] = {"pb1", "pb2","pb3", "pb4"};
  Arg          args[10];    /*  arg list             */
  register     int n;       /*  arg count            */
  XtAppContext app_context; /*  application context  */
  int          i;

/*  Initialize the toolkit, create application context, open display, 
    and  create a toplevel shell */
  toplevel = XtAppInitialize (&app_context, "Formdemo", NULL, 0, &argc, argv,
  NULL, args, 0);

/*  Create a form widget in which to place the pushbuttons */
  n = 0;
  form = XmCreateForm (toplevel, "form", args, n);

/*  Manage the form widget */
  XtManageChild (form);

  for (i=0; i < XtNumber(pbname); i++) {
    button[i] = XmCreatePushButton (form, pbname[i], args, n);
    XtAddCallback (button[i], XmNactivateCallback, activateCB, NULL);
  }
  XtManageChildren (button, XtNumber(button));

/* Set the constraint resources for the upper left button */
  n=0;
  XtSetArg (args[n], XmNtopOffset, 5); n++;
  XtSetArg (args[n], XmNleftOffset, 5); n++;
  XtSetArg (args[n], XmNbottomOffset, 15); n++;
  XtSetArg (args[n], XmNrightOffset, 15); n++;
  XtSetArg (args[n], XmNbottomWidget, button[2]); n++;
  XtSetArg (args[n], XmNrightWidget, button[1]); n++;
  XtSetArg (args[n], XmNtopAttachment, XmATTACH_FORM); n++;
  XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
  XtSetArg (args[n], XmNbottomAttachment, XmATTACH_WIDGET); n++;
  XtSetArg (args[n], XmNrightAttachment, XmATTACH_WIDGET); n++;
  XtSetValues (button[0], args, n);

/* Set the constraint resources for the upper right button */
  n=0;
  XtSetArg (args[n], XmNtopOffset, 5); n++;
  XtSetArg (args[n], XmNrightOffset, 5); n++;
  XtSetArg (args[n], XmNbottomOffset, 15); n++;
  XtSetArg (args[n], XmNbottomWidget, button[3]); n++;
  XtSetArg (args[n], XmNtopAttachment, XmATTACH_FORM); n++;
  XtSetArg (args[n], XmNrightAttachment, XmATTACH_FORM); n++;
  XtSetArg (args[n], XmNbottomAttachment, XmATTACH_WIDGET); n++;
  XtSetValues (button[1], args, n);

/* Set the constraint resources for the lower left button */
  n=0;
  XtSetArg (args[n], XmNbottomOffset, 5); n++;
  XtSetArg (args[n], XmNleftOffset, 5); n++;
  XtSetArg (args[n], XmNrightOffset, 15); n++;
  XtSetArg (args[n], XmNrightWidget, button[3]); n++;
  XtSetArg (args[n], XmNbottomAttachment, XmATTACH_FORM); n++;
  XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
  XtSetArg (args[n], XmNrightAttachment, XmATTACH_WIDGET); n++;
  XtSetValues (button[2], args, n);

/* Set the constraint resources for the lower right button */
  n=0;
  XtSetArg (args[n], XmNbottomOffset, 5); n++;
  XtSetArg (args[n], XmNrightOffset, 5); n++;
  XtSetArg (args[n], XmNbottomAttachment, XmATTACH_FORM); n++;
  XtSetArg (args[n], XmNrightAttachment, XmATTACH_FORM); n++;
  XtSetValues (button[3], args, n);

/*  Realize widgets  */
  XtRealizeWidget (toplevel);

/*  Process events  */
  XtAppMainLoop (app_context);
}

/*-------------------------------------------------------------
**  activateCB - callback for button
*/
void activateCB (w, client_data, call_data) 
  Widget   w;            /*  widget id              */
  XtPointer   client_data;  /*  data from application  */
  XtPointer   call_data;    /*  data from widget class */

{
/*  print message, free compound string memory, and terminate program  */
  printf ("PushButton selected.\n");
  XmStringFree(btn_text);
  exit (0);
}

